"""
Identifier:     KSC-SJ4-csst_common/status.py
Name:           status.py
Description:    CSST status
Author:         Bo Zhang
Created:        2022-10-04
Modified-History:
    2022-10-04, Bo Zhang, created
    2022-10-04, Bo Zhang, added CsstStatus
    2022-10-07, Bo Zhang, added Numpydoc docstring
"""
from enum import IntEnum


class CsstStatus(IntEnum):
    """
    The CSST Status class.

    This class provides a set of status which should be returned
    from each CSST L1 functional module.

    Examples
    --------
    >>> def f(num):
    >>>     if num > 0:
    >>>         return CsstStatus.PERFECT
    >>>     return CsstStatus.ERROR
    """
    PERFECT = 0
    WARNING = 1
    ERROR = 2
    # status list to be completed


class CsstResult:
    """
    Examples
    --------
    >>> CsstResult(CsstStatus.PERFECT, ["file1.fits", "file2.fits"])
    """
    def __init__(self, status: CsstStatus = CsstStatus.ERROR, file_list=[], **additional_output):
        assert isinstance(status, CsstStatus)
        assert type(file_list) is list
        self.status = status
        self.file_list = file_list
        self.additional_output = additional_output

    def __repr__(self):
        return f""" <CsstResult status={self.status}>
 - file_list: {self.file_list}
 - addtional_output: {self.additional_output} \n
"""


